# Aiko Python

## What is it?
This is Aiko (very simple operating system) port for Python and MicroPython. 
It is very light, simple and effective. You can use it like standard Aiko, but
in MicroPython, to make build projects on ESP or RPi pico very very simple.
